@@ -1,7 +1,7 @@
 // cmdline_show.cc                               -*-c++-*-
 //
 // Copyright (C) 2004, 2010 Daniel Burrows
-// Copyright (C) 2015 Manuel A. Fernandez Montecelo
+// Copyright (C) 2015-2016 Manuel A. Fernandez Montecelo
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -15,8 +15,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 
 // Local includes:
@@ -40,6 +40,7 @@
 // System includes:
 #include <cwidget/fragment.h>
 #include <cwidget/generic/util/transcode.h>
+#include <cwidget/generic/util/ssprintf.h>
 
 #include <apt-pkg/error.h>
 #include <apt-pkg/init.h>
@@ -58,6 +59,7 @@ using aptitude::cmdline::terminal_io;
 using aptitude::cmdline::terminal_metrics;
 using cwidget::fragf;
 using cwidget::fragment;
+using cwidget::util::ssprintf;
 using namespace std;
 
 ostream &operator<<(ostream &out, const cwidget::fragment_contents &contents)
@@ -204,10 +206,15 @@ static cwidget::fragment *archive_lst_frag(pkgCache::VerFileIterator vf,
     }
 }
 
-static const char *current_state_string(const pkgCache::PkgIterator& pkg, const pkgCache::VerIterator& ver)
+std::string current_state_string(const pkgCache::PkgIterator& pkg, const pkgCache::VerIterator& ver)
 {
-  if(!ver.end() && ver != pkg.CurrentVer())
-    return _("not installed");
+  if (!ver.end() && !pkg.CurrentVer().end() && ver != pkg.CurrentVer())
+    {
+      return ssprintf(_("%s (%s), upgrade available (%s)"),
+		      current_state_string(pkg, pkg.CurrentVer()).c_str(),
+		      pkg.CurrentVer().VerStr(),
+		      ver.VerStr());
+    }
 
   switch(pkg->CurrentState)
     {
@@ -296,7 +303,8 @@ static cwidget::fragment *state_fragment(pkgCache::PkgIterator pkg, pkgCache::Ve
   pkgDepCache::StateCache &state=(*apt_cache_file)[pkg];
   aptitudeDepCache::aptitude_state &estate=(*apt_cache_file)->get_ext_state(pkg);
 
-  const char *statestr=current_state_string(pkg, ver);
+  std::string state_str = current_state_string(pkg, ver);
+  const char* statestr = state_str.c_str();
 
   const char *holdstr="";
 
@@ -391,6 +399,8 @@ cw::fragment *version_file_fragment(const pkgCache::VerIterator &ver,
   pkgDepCache::StateCache &state = (*apt_cache_file)[pkg];
 
   fragments.push_back(cw::fragf("%s%s%n", _("Package: "), pkg.FullName(true).c_str()));
+  fragments.push_back(cw::fragf("%s%s%n", _("Version: "), ver.VerStr()));
+
   if((pkg->Flags & pkgCache::Flag::Essential)==pkgCache::Flag::Essential)
     fragments.push_back(cw::fragf("%s%s%n", _("Essential: "),  _("yes")));
 
@@ -413,7 +423,6 @@ cw::fragment *version_file_fragment(const pkgCache::VerIterator &ver,
   if(!multiarch.empty())
     fragments.push_back(cw::fragf("%s%s%n", _("Multi-Arch: "), multiarch.c_str()));
 
-  fragments.push_back(cw::fragf("%s%s%n", _("Version: "), ver.VerStr()));
   fragments.push_back(cw::fragf("%s%s%n", _("Priority: "),
 				const_cast<pkgCache::VerIterator &>(ver).PriorityType() ? const_cast<pkgCache::VerIterator &>(ver).PriorityType() : _("N/A")));
   fragments.push_back(cw::fragf("%s%s%n", _("Section: "),
@@ -425,14 +434,24 @@ cw::fragment *version_file_fragment(const pkgCache::VerIterator &ver,
 
   fragments.push_back(cw::fragf("%s%s%n", _("Uncompressed Size: "),
 			    SizeToStr(ver->InstalledSize).c_str()));
-  if(verbose>0)
+  if (verbose>0)
     {
       fragments.push_back(cw::fragf("%s%s%n", _("Compressed Size: "),
 				SizeToStr(ver->Size).c_str()));
       fragments.push_back(cw::fragf("%s%s%n", _("Filename: "),
 				rec.FileName().c_str()));
-      fragments.push_back(cw::fragf("%s%s%n", _("MD5sum: "),
-				rec.MD5Hash().c_str()));
+
+      // hashes (md5sum, sha*sum, etc)
+      std::vector<std::pair<std::string, std::string>> sorted_hashes;
+      for (const auto& it : rec.Hashes())
+	{
+	  sorted_hashes.push_back({ it.HashType(), it.HashValue() });
+	}
+      std::sort(sorted_hashes.begin(), sorted_hashes.end(), [](const auto& a, const auto& b) { return a.first < b.first; });
+      for (const auto& it : sorted_hashes)
+	{
+	  fragments.push_back(cw::fragf("%s: %s%n", it.first.c_str(), it.second.c_str()));
+	}
 
       if(verbose<2) // Show all archives in a list.
 	fragments.push_back(archive_lst_frag(ver.FileList(), _("Archive")));
@@ -520,10 +539,6 @@ bool do_cmdline_show_target(const pkgCache::PkgIterator &pkg,
 {
   if(verbose == 0 || has_explicit_source)
     {
-      // HACK: default to current-or-candidate behavior.  This should be
-      // done in a more up-front way :-(.
-      if(source == cmdline_version_cand)
-	source = cmdline_version_curr_or_cand;
       pkgCache::VerIterator ver = cmdline_find_ver(pkg, source, sourcestr);
 
       if(ver.end())
@@ -620,16 +635,13 @@ int cmdline_show(int argc, char *argv[], int verbose)
 {
   std::shared_ptr<terminal_io> term = create_terminal();
 
-  _error->DumpErrors();
+  aptitude::cmdline::on_apt_errors_print_and_die();
 
   std::shared_ptr<OpProgress> progress = make_text_progress(true, term, term, term);
-  apt_init(progress.get(), false);
+  bool operation_needs_lock = false;
+  apt_init(progress.get(), false, operation_needs_lock, nullptr);
 
-  if(_error->PendingError())
-    {
-      _error->DumpErrors();
-      return -1;
-    }
+  aptitude::cmdline::on_apt_errors_print_and_die();
 
   for(int i=1; i<argc; ++i)
     if(!do_cmdline_show(argv[i], verbose, term))
@@ -638,11 +650,7 @@ int cmdline_show(int argc, char *argv[], int verbose)
 	return -1;
       }
 
-  if(_error->PendingError())
-    {
-      _error->DumpErrors();
-      return -1;
-    }
+  aptitude::cmdline::on_apt_errors_print_and_die();
 
   return 0;
 }
