@@ -1,6 +1,7 @@
 // cmdline_versions.cc
 //
 // Copyright (C) 2010 Daniel Burrows
+// Copyright (C) 2015-2016 Manuel A. Fernandez Montecelo
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -14,8 +15,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 
 // Local includes:
@@ -175,7 +176,7 @@ namespace
       //   the VerIterator; much faster than parsing the pkgRecord
       //
       // - defaults to package name, no need to check if it's empty
-      output.push_back(ver.SourcePkgName() + " " + ver.SourceVerStr());
+      output.push_back(std::string(ver.SourcePkgName()) + " " + ver.SourceVerStr());
 #else
       // I don't think FileList() *can* be invalid; this is just
       // paranoia.
@@ -234,10 +235,10 @@ namespace
   // Print the matches against a group of versions.
   void show_version_match_list(const std::vector<std::pair<pkgCache::VerIterator, cw::util::ref_ptr<m::structural_match> > > &output,
                                const cw::config::column_definition_list &columns,
-                               int format_width,
-                               const unsigned int screen_width,
+                               int width,
                                bool disable_columns,
-                               bool show_package_names)
+                               bool show_package_names,
+			       const std::shared_ptr<terminal_output> &term_output)
   {
     for(std::vector<std::pair<pkgCache::VerIterator, cw::util::ref_ptr<m::structural_match> > >::const_iterator it = output.begin();
         it != output.end(); ++it)
@@ -247,20 +248,20 @@ namespace
                                       show_package_names,
                                       columns,
                                       0);
-        if(disable_columns)
-          printf("%ls\n", aptitude::cmdline::de_columnize(columns, columnizer, *p).c_str());
-        else
-          printf("%ls\n",
-                 columnizer.layout_columns(format_width == -1 ? screen_width : format_width,
-                                           *p).c_str());
+
+	std::wstring line;
+	if (disable_columns)
+	  line = aptitude::cmdline::de_columnize(columns, columnizer, *p);
+	else
+	  line = columnizer.layout_columns(width, *p);
+	printf("%ls\n", line.c_str());
       }
   }
 
   int do_search_versions(const std::vector<cw::util::ref_ptr<m::pattern> > &patterns,
                          pkg_sortpolicy *sort_policy,
                          const cw::config::column_definition_list &columns,
-                         int format_width,
-                         const unsigned int screen_width,
+                         int width,
                          bool disable_columns,
                          group_by_option group_by,
                          show_package_names_option show_package_names,
@@ -478,19 +479,19 @@ namespace
             // sorted them above.
             show_version_match_list(*it->second,
                                     columns,
-                                    format_width,
-                                    screen_width,
+                                    width,
                                     disable_columns,
-                                    do_show_package_names);
+                                    do_show_package_names,
+				    term_output);
           }
       }
     else
       show_version_match_list(output,
                               columns,
-                              format_width,
-                              screen_width,
+                              width,
                               disable_columns,
-                              do_show_package_names);
+                              do_show_package_names,
+			      term_output);
 
     return return_value;
   }
@@ -512,50 +513,39 @@ const char *GroupByParseException::what() const throw ()
 
 group_by_option parse_group_by_option(const std::string &option)
 {
-  // TRANSLATORS: if you add synonyms to the possible values here,
-  // please also use the translations in your manpage and in the error
-  // string below.
-  if(option == "archive" ||
-     option == P_("--group-by|archive"))
+  // TRANSLATORS: These are not translatable anymore
+
+  if(option == "archive")
     return group_by_archive;
 
-  else if(option == "auto" ||
-          option == P_("--group-by|auto"))
+  else if(option == "auto")
     return group_by_auto;
 
-  else if(option == "none" ||
-          option == P_("--group-by|none"))
+  else if(option == "none")
     return group_by_none;
 
-  else if(option == "package" ||
-          option == P_("--group-by|package"))
+  else if(option == "package")
     return group_by_package;
 
-  else if(option == "source-package" ||
-          option == P_("--group-by|source-package"))
+  else if(option == "source-package")
     return group_by_source_package;
 
-  else if(option == "source-version" ||
-          option == P_("--group-by|source-version"))
+  else if(option == "source-version")
     return group_by_source_version;
 
   else
-    // TRANSLATORS: --group-by is the argument name and shouldn't
-    // be translated.
-    throw GroupByParseException((boost::format(_("Invalid package grouping mode \"%s\" (should be \"auto\", \"none\", \"package\", or \"source-package\")"))
+    throw GroupByParseException((boost::format(_("Invalid package grouping mode \"%s\" (should be \"auto\", \"none\", \"package\", \"source-package\" or \"source-version\")"))
                                  % option).str());
 }
 
 int cmdline_versions(int argc, char *argv[], const char *status_fname,
-                     std::string display_format, std::string width,
+                     std::string display_format, std::string width_cfg,
                      std::string sort, bool disable_columns, bool debug,
                      group_by_option group_by,
                      show_package_names_option show_package_names)
 {
   std::shared_ptr<terminal_io> term = create_terminal();
 
-  int real_width=-1;
-
   pkg_item::pkg_columnizer::setup_columns();
 
   pkg_sortpolicy *sort_policy = parse_sortpolicy(sort);
@@ -568,13 +558,19 @@ int cmdline_versions(int argc, char *argv[], const char *status_fname,
 
   _error->DumpErrors();
 
-  const unsigned int screen_width = term->get_screen_width();
-  if(!width.empty())
+  // do not truncate to 80 cols on redirections, pipes, etc -- see #445206,
+  // #496728, #815690.  Either use explicit width set by the
+  // command-line/config, or disable columns.
+  int explicit_width = -1;
+  if (!width_cfg.empty())
     {
-      unsigned long tmp = screen_width;
-      StrToNum(width.c_str(), tmp, width.size());
-      real_width = tmp;
+      explicit_width = std::stoi(width_cfg);
     }
+  if (!term->output_is_a_terminal() && !(explicit_width > 0))
+    {
+      disable_columns = true;
+    }
+  int width = (explicit_width > 0) ? explicit_width : term->get_screen_width();
 
   if(!disable_columns && !pkg_item::pkg_columnizer::check_valid_display_format(display_format, PACKAGE "::CmdLine::Version-Display-Format" " (or -F)"))
     {
@@ -598,6 +594,7 @@ int cmdline_versions(int argc, char *argv[], const char *status_fname,
 
   if(columns.get() == NULL)
     {
+      fprintf(stderr, _("%s: Could not parse column definitions: '%ls'\n"), "versions", wdisplay_format.c_str());
       _error->DumpErrors();
       return -1;
     }
@@ -609,14 +606,10 @@ int cmdline_versions(int argc, char *argv[], const char *status_fname,
     }
 
   OpProgress progress;
+  bool operation_needs_lock = false;
+  apt_init(&progress, true, operation_needs_lock, status_fname);
 
-  apt_init(&progress, true, status_fname);
-
-  if(_error->PendingError())
-    {
-      _error->DumpErrors();
-      return -1;
-    }
+  aptitude::cmdline::on_apt_errors_print_and_die();
 
   std::vector<cw::util::ref_ptr<m::pattern> > matchers;
 
@@ -624,22 +617,37 @@ int cmdline_versions(int argc, char *argv[], const char *status_fname,
     {
       const char * const arg = argv[i];
 
-      cw::util::ref_ptr<m::pattern> m = m::parse(arg);
-      if(!m.valid())
+      cw::util::ref_ptr<m::pattern> m;
+      if (m::is_pattern(arg))
 	{
-	  _error->DumpErrors();
-
-	  return -1;
+	  m = m::parse(arg);
+	}
+      else
+	{
+	  pkgCache::PkgIterator pkg = (*apt_cache_file)->FindPkg(arg);
+	  if (!pkg.end())
+	    {
+	      m = m::pattern::make_exact_name(pkg.Name());
+	    }
 	}
 
-      matchers.push_back(m);
+      if (m.valid())
+	{
+	  matchers.push_back(m);
+	}
+      else
+	{
+	  _error->Error(_("Argument is neither a package name nor a pattern: '%s'"), arg);
+	}
     }
 
+  // check for errors after parsing arguments
+  aptitude::cmdline::on_apt_errors_print_and_die();
+
   return do_search_versions(matchers,
                             sort_policy,
                             *columns,
-                            real_width,
-                            screen_width,
+                            width,
                             disable_columns,
                             group_by,
                             show_package_names,
