@@ -1,6 +1,7 @@
 /** \file globals.cc */
 
 // Copyright (C) 2010 Daniel Burrows
+// Copyright (C) 2015-2016 Manuel A. Fernandez Montecelo
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -14,8 +15,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 #include <memory>
 
@@ -27,13 +28,6 @@ class resolver_manager;
 class signalling_config;
 class undo_list;
 
-namespace aptitude
-{
-  namespace util
-  {
-    class file_cache;
-  }
-}
 
 // Definitions of global pointers exposed in apt.h.  They are defined
 // here so that test code can get away with just linking in globals.o
@@ -45,5 +39,4 @@ pkgSourceList *apt_source_list=NULL;
 undo_list *apt_undos=NULL;
 resolver_manager *resman = NULL;
 
-std::shared_ptr<aptitude::util::file_cache> download_cache;
-
+bool shutdown_in_progress = false;
