@@ -17,8 +17,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; see the file COPYING.  If not, write to
-//  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-//  Boston, MA 02111-1307, USA.
+//  the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+//  Boston, MA 02110-1301, USA.
 
 #include "changelog.h"
 #include "aptitude.h"
@@ -864,8 +864,9 @@ namespace gui
 		  << " under the cache URI "
 		  << uri);
 
-	predigested_file = download_cache->getItem(uri);
-	if(predigested_file.valid())
+	auto download_cache = get_download_cache();
+	predigested_file = download_cache && download_cache->getItem(uri);
+	if (predigested_file.valid())
 	  LOG_TRACE(logger, "Changelog preparation thread: found a predigested changelog for "
 		    << req->get_target_info()->get_source_package()
 		    << " " << req->get_target_info()->get_source_version()
