@@ -1,6 +1,7 @@
 /** \file test_cmdline_download_status_display.cc */
 
 // Copyright (C) 2010-2011 Daniel Burrows
+// Copyright (C) 2015-2018 Manuel A. Fernandez Montecelo
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -30,11 +31,12 @@
 #include <gtest/gtest.h>
 
 #include <memory>
+#include <optional>
 
 using aptitude::cmdline::create_cmdline_download_status_display;
 using aptitude::cmdline::download_status_display;
 using aptitude::views::download_progress;
-using boost::optional;
+using std::optional;
 using testing::Return;
 using testing::StrEq;
 using testing::TestWithParam;
